==> gnade_1.2.0.orig.tar.gz: gnade-1.2.0/samples/sample_db/create_user.mimer.sql <==
-- ----------------------------------------------------------------------------
--                                                                           --
--                      GNADE  : GNu Ada Database Environment                --
--                                                                           --
--  Filename        : $Source: /var/cvs/gnuada/gnade/samples/sample_db/create_user.mimer.sql.in,v $
--  Description     : Create the user for the test code
--  Author          : Sune Falck
--  Created On      : 6-Apr-2001
--  Last Modified By: $Author: me $
--  Last Modified On: $Date: 2001/04/07 20:20:42 $
--  Status          : $State: Exp $
--
--  Copyright (C) 2000-2001
--
--  GNADE is copyrighted by the persons and institutions enumerated in the   --
--  AUTHORS file. This file is located in the root directory of the          --
--  GNADE distribution.                                                      --
--                                                                           --
--  GNADE is free software;  you can redistribute it  and/or modify it under --
--  terms of the  GNU General Public License as published  by the Free Soft- --
--  ware  Foundation;  either version 2,  or (at your option) any later ver- --
--  sion.  GNAT is distributed in the hope that it will be useful, but WITH- --
--  OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
--  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
--  for  more details.  You should have  received  a copy of the GNU General --
--  Public License  distributed with GNAT;  see file COPYING.  If not, write --
--  to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
--  MA 02111-1307, USA.                                                      --
--                                                                           --
--  As a special exception,  if other files  instantiate  generics from      --
--  GNADE Ada units, or you link GNADE Ada units or libraries with other     --
--  files  to produce an executable, these  units or libraries do not by     --
--  itself cause the resulting  executable  to  be covered  by the  GNU      --
--  General  Public  License.  This exception does not however invalidate    --
--  any other reasons why  the executable file  might be covered by the      --
--  GNU Public License.                                                      --
--                                                                           --
--  GNADE is implemented to work with GNAT, the GNU Ada compiler.            --
--                                                                           --
-- ----------------------------------------------------------------------------          
CREATE IDENT GNADE AS USER USING 'gnade';
GRANT DATABANK TO GNADE WITH GRANT OPTION;

==> gnade_1.5.1.orig.tar.gz: gnade-1.5.1.orig/samples/sample_db/create_user.mimer.sql <==
-- ----------------------------------------------------------------------------
--                                                                           --
--                      GNADE  : GNu Ada Database Environment                --
--                                                                           --
--  Filename        : $Source: /cvsroot/gnade/gnade/samples/sample_db/create_user.mimer.sql.in,v $
--  Description     : Create the user for the test code
--  Author          : Sune Falck
--  Created On      : 6-Apr-2001
--  Last Modified By: $Author: merdmann $
--  Last Modified On: $Date: 2004/03/06 20:01:08 $
--  Status          : $State: Exp $
--
--  Copyright (C) 2000-2001
--
--  GNADE is copyrighted by the persons and institutions enumerated in the   --
--  AUTHORS file. This file is located in the root directory of the          --
--  GNADE distribution.                                                      --
--                                                                           --
--  GNADE is free software;  you can redistribute it  and/or modify it under --
--  terms of the  GNU General Public License as published  by the Free Soft- --
--  ware  Foundation;  either version 2,  or (at your option) any later ver- --
--  sion.  GNAT is distributed in the hope that it will be useful, but WITH- --
--  OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
--  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
--  for  more details.  You should have  received  a copy of the GNU General --
--  Public License  distributed with GNAT;  see file COPYING.  If not, write --
--  to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
--  MA 02111-1307, USA.                                                      --
--                                                                           --
--  As a special exception,  if other files  instantiate  generics from      --
--  GNADE Ada units, or you link GNADE Ada units or libraries with other     --
--  files  to produce an executable, these  units or libraries do not by     --
--  itself cause the resulting  executable  to  be covered  by the  GNU      --
--  General  Public  License.  This exception does not however invalidate    --
--  any other reasons why  the executable file  might be covered by the      --
--  GNU Public License.                                                      --
--                                                                           --
--  GNADE is implemented to work with GNAT, the GNU Ada compiler.            --
--                                                                           --
-- ----------------------------------------------------------------------------          
CREATE DATABANK $SAMPLEDB OF 1000 PAGES IN '$SAMPLEDB.dbf' WITH LOG OPTION;
CREATE IDENT $DBUSER AS USER USING '$DBPASSWD';
GRANT DATABANK TO $DBUSER WITH GRANT OPTION;
GRANT TABLE ON $SAMPLEDB TO $DBUSER;
